@@ -134,7 +134,7 @@ impl Ticket {
         }
     }
 
-    pub fn is_ticket_valid(&self, addr: Option<IpAddr>, is_check_addr: bool) -> ResultCode {
+    pub fn is_ticket_valid(&self, addr: &Option<IpAddr>, is_check_addr: bool) -> ResultCode {
         if is_check_addr {
             if let Some(a) = addr {
                 if self.user_addr != a.to_string() {
